package es.kauron.jstudy.model;

import javafx.beans.property.SimpleStringProperty;
import javafx.beans.property.StringProperty;

import java.io.*;
import java.util.ArrayList;
import java.util.InputMismatchException;
import java.util.List;
import java.util.Scanner;

public class TestItem {
    private StringProperty question, answer;

    public TestItem(SimpleStringProperty question, SimpleStringProperty answer) {
        this.question = question;
        this.answer = answer;
    }

    public TestItem(TestItem item) {
        this(item.getQuestion(), item.getAnswer());
    }

    public TestItem(String question, String answer) {
        this(new SimpleStringProperty(question), new SimpleStringProperty(answer));
    }

    public String getQuestion() {
        return question.get();
    }

    public StringProperty questionProperty() {
        return question;
    }

    public String getAnswer() {
        return answer.get();
    }

    public StringProperty answerProperty() {
        return answer;
    }

    public boolean isValid() {
        return !question.get().isEmpty() && !answer.get().isEmpty();
    }

    public boolean checkAnswer(String answer, boolean sensible) {
        return sensible ? getAnswer().equals(answer) : getAnswer().equalsIgnoreCase(answer);
    }

    public static void saveTo(File file, List<TestItem> data) {
        try {
            OutputStreamWriter writer = new FileWriter(file);
            for (TestItem item : data) {
                writer.write(item.getQuestion() + "::" + item.getAnswer() + "\n");
            }
            writer.flush();
            writer.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static List<TestItem> loadFrom(File file) {
        List<TestItem> list = new ArrayList<>();
        try {
            Scanner in = new Scanner(file);
            while (in.hasNextLine()) {
                String line = in.nextLine();
                int index = line.indexOf("::");
                String question = line.substring(0, index);
                String answer   = line.substring(index + 2);
                list.add(new TestItem(question, answer));
                System.err.println(question + " :: " + answer);
            }
        } catch (FileNotFoundException | InputMismatchException e) {
            e.printStackTrace();
        }
        return list;
    }

}
